# Aerial Robot Environments

## Tasks

> No tasks are implemented at the moment.

## Demos

### Ingenuity

```bash
.docker/run.bash -e SRB_SCENARIO=mars scripts/teleop.py --env ingenuity
```

![](../../_images/envs/ingenuity.jpg)
